yakumo.keystone.v3

Package yakumo :: Package keystone :: Package v3 |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.keystone.v3

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Sub client class for Identity V3 API
    18  """
    19
    20  from . import credential
    21  from . import domain
    22  from . import endpoint
    23  from . import group
    24  from . import project
    25  from . import role
    26  from . import region
    27  from . import service
    28  from . import user
    29
    30
    31 -class Client(object):
    32
    33 -    def __init__(self, client, **kwargs):
    34          self.region = region.Manager(client, **kwargs)
    35          self.service = service.Manager(client, **kwargs)
    36          self.endpoint = endpoint.Manager(client, **kwargs)
    37          self.role = role.Manager(client, **kwargs)
    38          self.domain = domain.Manager(client, **kwargs)
    39          self.project = project.Manager(client, **kwargs)
    40          self.group = group.Manager(client, **kwargs)
    41          self.user = user.Manager(client, **kwargs)
    42          self.credential = credential.Manager(client, **kwargs)
    43
    44          client.region = self.region
    45          client.service = self.service
    46          client.endpoint = self.endpoint
    47          client.role = self.role
    48          client.domain = self.domain
    49          client.project = self.project
    50          client.group = self.group
    51          client.user = self.user
    52          client.credential = self.credential
    53